//	AcidTileSet.h - Tile set using Acid's tiles.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ACIDTILESET_H_
#define ACIDTILESET_H_

#include "TileSet.h"

#include <vector>

///	Tile set using Acid's tiles.
class AcidTileSet : public TileSet
{
  public:
	///	Constructor.
	AcidTileSet();
	///	Destructor.
	~AcidTileSet();

	///	Loads the tiles in this set.
	void loadTiles(Drawer *d);

	///	Returns the number of ground tiles in this set.
	int getNumGroundTiles() const {return ground.size();};
	///	Returns the number of destructable tiles in this set.
	int getNumWallTiles() const {return wall.size();};
	///	Returns the number of impassable tiles in this set.
	int getNumImpassableTiles() const {return impassable.size();};

	///	Returns the size of the tiles (tiles are assumed to be square).
	int getTileSize() const {return 16;};
	///	Returns the tileset's author.
	std::string getAuthor() const {return "acid";};

	///	Returns the indexed ground tile.
	uint32_t getGroundTile(int i) {return ground[i%ground.size()];};
	///	Returns the indexed destructable tile.
	uint32_t getWallTile(int i) {return wall[i%wall.size()];};
	///	Returns the indexed impassable tile.
	uint32_t getImpassableTile(int i) {return impassable[i%impassable.size()];};
  private:
	///	The ground tiles.
	std::vector<uint32_t> ground;
	///	The wall tiles.
	std::vector<uint32_t> wall;
	///	The impassable tiles.
	std::vector<uint32_t> impassable;
};

#endif
