//	EnemySpawner.cpp - Spawns enemies for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "EnemySpawner.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "Random.h"

//------------------------------------------------------------------------------
uint32_t EnemySpawner::image = 0;
uint32_t EnemySpawner::flash = 0;

//------------------------------------------------------------------------------
EnemySpawner::EnemySpawner(int x, int y, int i):
xPos(x),
yPos(y),
index(i),
health(48),
spawnTimer(120)
{
	spawnTimer = 90 + (int)(Random::getGlobal().getRandomFloat() * 30.0f);
}

//------------------------------------------------------------------------------
EnemySpawner::~EnemySpawner()
{
	
}

//------------------------------------------------------------------------------
bool EnemySpawner::spawnTime()
{
	bool retval = false;

	--spawnTimer;

	if(!spawnTimer)
	{
		retval = true;
		spawnTimer = 180;
	}

	return retval;
}

//------------------------------------------------------------------------------
void EnemySpawner::draw(Drawer *d)
{
	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::enemyspawner_png, Images::enemyspawner_pngSize);
		image = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::enemyspawnerflash_png, Images::enemyspawnerflash_pngSize);
		flash = d->loadImage(data.data, data.width, data.height);
	}

	if(spawnTimer < 6)
		d->drawImage(flash, xPos, yPos);
	else
		d->drawImage(image, xPos, yPos);
}

//------------------------------------------------------------------------------
bool EnemySpawner::decrementHealth()
{
	bool retval = false;

	--health;
	if(health == 0)
		retval = true;

	return retval;
}
