//	EnemySpawner.h - Spawns enemies for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ENEMYSPAWNER_H_
#define ENEMYSPAWNER_H_

#include <stdint.h>

class Drawer;

///	Spawns enemies for the gauntlet stage.
class EnemySpawner
{
  public:
	///	Constructor.
	EnemySpawner(int x, int y, int i);
	///	Destructor.
	~EnemySpawner();

	///	Returns true if it's time to spawn a new enemy.
	bool spawnTime();
	///	Draws the enemy spawner.
	void draw(Drawer *d);

	///	Decrements this spawner's health.
	bool decrementHealth();

	///	Returns the spawner's position.
	int getX() const {return xPos;};
	///	Returns the spawner's position.
	int getY() const {return yPos;};
	///	Returns the spawner's index in the level map.
	int getIndex() const {return index;};
  private:
	///	The spawner's main image.
	static uint32_t image;
	///	The spawner's flash image.
	static uint32_t flash;

	///	The spawner's position in the level.
	int xPos;
	///	The spawner's position in the level.
	int yPos;
	///	Which tile this spawner is in the map.
	int index;
	///	The spawner's health.
	int health;

	///	Used to determine when to spawn new enemies.
	int spawnTimer;
};

#endif
