//	GauntletPlayer.cpp - The player character for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "GauntletPlayer.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

#include <cmath>

//------------------------------------------------------------------------------
uint32_t GauntletPlayer::up[3] = {0, 0, 0};
uint32_t GauntletPlayer::right[3] = {0, 0, 0};
uint32_t GauntletPlayer::down[3] = {0, 0, 0};

//------------------------------------------------------------------------------
GauntletPlayer::GauntletPlayer():
xPos(102.0f),
yPos(296.0f),
lives(3),
invinciTimer(90),
numBigBullets(0),
image(0),
frame(0),
prevFrame(0),
animTimer(15),
upIsDown(false),
downIsDown(false),
rightIsDown(false),
leftIsDown(false)
{
	
}

//------------------------------------------------------------------------------
GauntletPlayer::~GauntletPlayer()
{
	
}

//------------------------------------------------------------------------------
void GauntletPlayer::move(uint8_t *map, int width, int height)
{
	int x, y;
	int x2, y2;
	float xRes, yRes;
	bool moving = false;

	xRes = xPos;
	yRes = yPos;

	//Move according to the player input.
	if(upIsDown && !downIsDown)
	{
		yRes -= 1.0f;
		image = 0;
		moving = true;
	}
	else if(!upIsDown && downIsDown)
	{
		yRes += 1.0f;
		image = 2;
		moving = true;
	}
	if(leftIsDown && !rightIsDown)
	{
		xRes -= 1.0f;
		if(!upIsDown)
			image = 3;
		moving = true;
	}
	else if(!leftIsDown && rightIsDown)
	{
		xRes += 1.0f;
		if(!upIsDown)
			image = 1;
		moving = true;
	}

	if(xRes < 0.0f)
		xRes = 0.0f;
	else if(xRes > (224.0f-16.0f))
		xRes = 224.0f-16.0f;
	if(yRes < -24.0f)
		yRes = -24.0f;
	else if(yRes > (320.0f-24.0f))
		yRes = 320.0f-24.0f;

	//Check collision with the level.
	x = xRes/32;
	y = yRes/32;
	x2 = (xRes+16.0f)/32;
	if(x2 >= width)
		x2 = width-1;
	y2 = (yRes+24.0f)/32;
	if(y2 >= height)
		y2 = height-1;

	if(leftIsDown || rightIsDown || upIsDown || downIsDown)
	{
		if(leftIsDown && !rightIsDown)
		{
			if((map[(y*width)+x] > 63) || (map[(y2*width)+x] > 63))
			{
				if(upIsDown && !downIsDown)
				{
					if(map[(y2*width)+x] < 64)
						yRes = yPos;
					else if(map[(y*width)+x2] < 64)
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else if(!upIsDown && downIsDown)
				{
					if(map[(y*width)+x] < 64)
						yRes = yPos;
					else if(map[(y2*width)+x2] < 64)
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else
					xRes = xPos;
			}
		}
		else if(!leftIsDown && rightIsDown)
		{
			if((map[(y*width)+x2] > 63) || (map[(y2*width)+x2] > 63))
			{
				if(upIsDown && !downIsDown)
				{
					if(map[(y2*width)+x2] < 64)
						yRes = yPos;
					else if(map[(y*width)+x] < 64)
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else if(!upIsDown && downIsDown)
				{
					if(map[(y*width)+x2] < 64)
						yRes = yPos;
					else if(map[(y2*width)+x] < 64)
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else
					xRes = xPos;
			}
		}
		else if(upIsDown && !downIsDown)
		{
			if((map[(y*width)+x] > 63) || (map[(y*width)+x2] > 63))
				yRes = yPos;
		}
		else if(!upIsDown && downIsDown)
		{
			if((map[(y2*width)+x] > 63) || (map[(y2*width)+x2] > 63))
				yRes = yPos;
		}
	}

	xPos = xRes;
	yPos = yRes;

	//Update the animation variables.
	if(!moving)
		frame = -1;
	else
	{
		--animTimer;
		if(animTimer == 0)
		{
			animTimer = 15;
			if((image == 0) || (image == 2))
			{
				prevFrame = frame;
				frame = (frame+1)%2;
			}
			else
			{
				if(frame > -1)
					frame = -1;
				else if(prevFrame == 0)
				{
					frame = 1;
					prevFrame = frame;
				}
				else
				{
					frame = 0;
					prevFrame = frame;
				}
			}
		}
	}
}

//------------------------------------------------------------------------------
void GauntletPlayer::draw(Drawer *d)
{
	float alpha;

	if(!up[0])
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::playerup1_png, Images::playerup1_pngSize);
		up[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerup2_png, Images::playerup2_pngSize);
		up[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerup3_png, Images::playerup3_pngSize);
		up[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerright1_png, Images::playerright1_pngSize);
		right[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerright2_png, Images::playerright2_pngSize);
		right[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerright3_png, Images::playerright3_pngSize);
		right[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerdown1_png, Images::playerdown1_pngSize);
		down[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerdown2_png, Images::playerdown2_pngSize);
		down[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::playerdown3_png, Images::playerdown3_pngSize);
		down[2] = d->loadImage(data.data, data.width, data.height);
	}

	if(!invinciTimer)
		alpha = 1.0f;
	else
	{
		--invinciTimer;

		alpha = sinf(((float)invinciTimer/15.0f) * 2.0f * 3.14159265f);
		alpha *= 0.25f;
		alpha += 0.75f;
	}

	switch(image)
	{
		case 0: //Up.
			d->drawImage(up[frame+1], xPos, yPos, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, alpha);
			break;
		case 1: //Right.
			d->drawImage(right[frame+1], xPos, yPos, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, alpha);
			break;
		case 2: //Down.
			d->drawImage(down[frame+1], xPos, yPos, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, alpha);
			break;
		case 3: //Left.
			d->drawImage(right[frame+1], xPos+16, yPos, -1.0f, 1.0f, 1.0f, 1.0f, 1.0f, alpha);
			break;
	}
}

//------------------------------------------------------------------------------
bool GauntletPlayer::decrementLives()
{
	bool retval = false;

	if(!invinciTimer)
	{
		--lives;
		if(!lives)
			retval = true;
		else
		{
			xPos = 102.0f;
			yPos = 296.0f;
			invinciTimer = 90;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void GauntletPlayer::incrementLives()
{
	++lives;
}

//------------------------------------------------------------------------------
void GauntletPlayer::useBigBullets()
{
	numBigBullets = 60;
}

//------------------------------------------------------------------------------
void GauntletPlayer::decrementBigBullets()
{
	--numBigBullets;
}

//------------------------------------------------------------------------------
void GauntletPlayer::moveLeft(bool val)
{
	leftIsDown = val;
}

//------------------------------------------------------------------------------
void GauntletPlayer::moveRight(bool val)
{
	rightIsDown = val;
}

//------------------------------------------------------------------------------
void GauntletPlayer::moveUp(bool val)
{
	upIsDown = val;
}

//------------------------------------------------------------------------------
void GauntletPlayer::moveDown(bool val)
{
	downIsDown = val;
}
