//	GauntletPlayer.h - The player character for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GAUNTLETPLAYER_H_
#define GAUNTLETPLAYER_H_

#include <stdint.h>

class Drawer;

///	The player character for the gauntlet stage.
class GauntletPlayer
{
  public:
	///	Constructor.
	GauntletPlayer();
	///	Destructor.
	~GauntletPlayer();

	///	Moves the player.
	void move(uint8_t *map, int width, int height);
	///	Draws the player.
	void draw(Drawer *d);

	///	Decrements the player's lives, moves them back to the level start.
	bool decrementLives();
	///	Increments the player's lives.
	void incrementLives();

	///	Switches the player to using the big bullets.
	void useBigBullets();
	///	Returns how many big bullets the player has left.
	int getNumBigBullets() const {return numBigBullets;};
	///	Decrements the number of big bullets the player has.
	void decrementBigBullets();

	///	Moves the player.
	void moveLeft(bool val);
	///	Moves the player.
	void moveRight(bool val);
	///	Moves the player.
	void moveUp(bool val);
	///	Moves the player.
	void moveDown(bool val);

	///	Returns the player's position.
	float getX() const {return xPos;};
	///	Returns the player's position.
	float getY() const {return yPos;};
	///	Returns the player's number of lives.
	int getLives() const {return lives;};

	///	Returns the player's movement key values.
	bool getLeft() const {return leftIsDown;};
	///	Returns the player's movement key values.
	bool getRight() const {return rightIsDown;};
	///	Returns the player's movement key values.
	bool getUp() const {return upIsDown;};
	///	Returns the player's movement key values.
	bool getDown() const {return downIsDown;};
	///	Returns which image the player's on.
	int getImage() const {return image;};
  private:
	///	The Player's upwards images.
	static uint32_t up[3];
	///	The Player's rightwards images.
	static uint32_t right[3];
	///	The Player's downwards images.
	static uint32_t down[3];

	///	The player's position.
	float xPos;
	///	The player's position.
	float yPos;
	///	The player's lives.
	int lives;
	///	If the player's currently invincible.
	int invinciTimer;

	///	How many big bullets the player has at their disposal.
	int numBigBullets;

	///	Which set of images to use.
	int image;
	///	Which animation frame we're on.
	int frame;
	///	The previous animation frame.
	int prevFrame;
	///	Used to time the animations correctly.
	int animTimer;

	///	Used to move the player.
	bool upIsDown;
	///	Used to move the player.
	bool downIsDown;
	///	Used to move the player.
	bool leftIsDown;
	///	Used to move the player.
	bool rightIsDown;
};

#endif
