//	GiantSkeleton.cpp - Final boss guy.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "GiantSkeleton.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t GiantSkeleton::down[3] = {0, 0, 0};

//------------------------------------------------------------------------------
GiantSkeleton::GiantSkeleton():
yPos(-(32.0f*7.0f)),
health(512),
frame(0),
prevFrame(0),
animTimer(20)
{
	
}

//------------------------------------------------------------------------------
GiantSkeleton::~GiantSkeleton()
{
	
}

//------------------------------------------------------------------------------
bool GiantSkeleton::move()
{
	bool retval = false;

	//Update the animation variables.
	--animTimer;
	if(animTimer == 0)
	{
		animTimer = 20;
		if(frame > -1)
		{
			frame = -1;
			retval = true;
			yPos += 2.0f;
		}
		else if(prevFrame == 0)
		{
			frame = 1;
			prevFrame = frame;
		}
		else
		{
			frame = 0;
			prevFrame = frame;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void GiantSkeleton::draw(Drawer *d)
{
	if(!down[0])
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::skeletondown1_png, Images::skeletondown1_pngSize);
		down[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletondown2_png, Images::skeletondown2_pngSize);
		down[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletondown3_png, Images::skeletondown3_pngSize);
		down[2] = d->loadImage(data.data, data.width, data.height);
	}

	if(health > 0)
		d->drawImage(down[frame+1], 0.0f, yPos, 7.0f, 7.0f);
}

//------------------------------------------------------------------------------
bool GiantSkeleton::decrementHealth(int val)
{
	bool retval = false;

	health -= val;
	if(health <= 0)
		retval = true;

	return retval;
}
