//	GiantSkeleton.h - Final boss guy.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GIANTSKELETON_H_
#define GIANTSKELETON_H_

#include <stdint.h>

class Drawer;

///	Final boss guy.
class GiantSkeleton
{
  public:
	///	Constructor.
	GiantSkeleton();
	///	Destructor.
	~GiantSkeleton();

	///	Moves the GiantSkeleton.  Returns true if the screen should shake.
	bool move();
	///	Draws the GiantSkeleton.
	void draw(Drawer *d);

	///	Decrement the GiantSkeleton's health, returns true if the GiantSkeleton died.
	bool decrementHealth(int val);

	///	Returns the GiantSkeleton's position.
	float getY() const {return yPos;};
  private:
	///	The GiantSkeleton's downwards images.
	static uint32_t down[3];

	///	The GiantSkeleton's position.
	float yPos;
	///	The GiantSkeleton's health.
	int health;

	///	Which animation frame we're on.
	int frame;
	///	The previous animation frame.
	int prevFrame;
	///	Used to time the animations correctly.
	int animTimer;
};

#endif
