//	PlayerShip.cpp - The player's ship for the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "PlayerShip.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

#include <cmath>

//------------------------------------------------------------------------------
uint32_t PlayerShip::image = 0;

//------------------------------------------------------------------------------
PlayerShip::PlayerShip():
x(102.0f),
y(320.0f),
lives(3),
invinciTimer(90),
leftIsDown(false),
rightIsDown(false),
upIsDown(false),
downIsDown(false)
{
	int i;

	for(i=0;i<TrailSize;++i)
	{
		prevX[i] = 102.0f;
		prevY[i] = 320.0f;
	}
}

//------------------------------------------------------------------------------
PlayerShip::~PlayerShip()
{
	
}

//------------------------------------------------------------------------------
void PlayerShip::draw(Drawer *d)
{
	int i;
	float alpha;

	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::ship_png, Images::ship_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	//Update the ship's trail.
	for(i=(TrailSize-1);i>0;--i)
	{
		prevX[i] = prevX[i-1];
		prevY[i] = prevY[i-1];
	}
	prevX[0] = x;
	prevY[0] = y;

	//Move the ship.
	if(leftIsDown && !rightIsDown)
		x -= 1.5f;
	else if(rightIsDown && !leftIsDown)
		x += 1.5f;
	if(upIsDown && !downIsDown)
		y -= 1.5f;
	else if(downIsDown && !upIsDown)
		y += 1.5f;

	//Keep it within its bounds.
	if(x < 0)
		x = 0;
	else if(x > (224-20))
		x = 224-20;
	if(y < 0)
		y = 0;
	else if(y > (320-20))
		y -= 1.5f;

	if(!invinciTimer)
		alpha = 1.0f;
	else
	{
		--invinciTimer;

		alpha = sinf(((float)invinciTimer/15.0f) * 2.0f * 3.14159265f);
		alpha *= 0.25f;
		alpha += 0.75f;
	}

	//Draw the ship's trail.
	for(i=(TrailSize-1);i>=0;--i)
	{
		d->drawImage(image,
					 prevX[i],
					 prevY[i],
					 1.0f,
					 1.0f,
					 1.0f,
					 1.0f,
					 1.0f,
					 (1.0f-((float)i/(float)TrailSize))*0.25f);
	}

	//Draw the ship.
	d->drawImage(image, x, y, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, alpha);
}

//------------------------------------------------------------------------------
bool PlayerShip::decrementLives()
{
	bool retval = false;

	if(!invinciTimer)
	{
		--lives;
		if(!lives)
			retval = true;
		else
		{
			x = 102.0f;
			y = 320.0f;
			invinciTimer = 90;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void PlayerShip::moveLeft(bool val)
{
	leftIsDown = val;
}

//------------------------------------------------------------------------------
void PlayerShip::moveRight(bool val)
{
	rightIsDown = val;
}

//------------------------------------------------------------------------------
void PlayerShip::moveUp(bool val)
{
	upIsDown = val;
}

//------------------------------------------------------------------------------
void PlayerShip::moveDown(bool val)
{
	downIsDown = val;
}
