//	PlayerShip.h - The player's ship for the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYERSHIP_H_
#define PLAYERSHIP_H_

#include <stdint.h>

class Drawer;

///	The player's ship for the shooter section.
class PlayerShip
{
  public:
	///	Constructor.
	PlayerShip();
	///	Destructor.
	~PlayerShip();

	///	Draws the ship.
	void draw(Drawer *d);

	///	Decrements the player's lives, moves them back to the level start.
	bool decrementLives();

	///	Moves the ship.
	void moveLeft(bool val);
	///	Moves the ship.
	void moveRight(bool val);
	///	Moves the ship.
	void moveUp(bool val);
	///	Moves the ship.
	void moveDown(bool val);

	///	Returns the ship's position.
	float getX() const {return x;};
	///	Returns the ship's position.
	float getY() const {return y;};
	///	Returns the player's lives.
	int getLives() const {return lives;};
  private:
	///	The size of the ship's trail.
	enum
	{
		TrailSize = 6
	};

	///	The ship's image.
	static uint32_t image;

	///	The ship's position.
	float x;
	///	The ship's position.
	float y;
	///	The player's lives.
	int lives;
	///	If the player's currently invincible.
	int invinciTimer;

	///	Used to draw a trail of ships.
	float prevX[TrailSize];
	///	Used to draw a trail of ships.
	float prevY[TrailSize];

	///	If the ship should be moving left.
	bool leftIsDown;
	///	If the ship should be moving right.
	bool rightIsDown;
	///	If the ship should be moving up.
	bool upIsDown;
	///	If the ship should be moving down.
	bool downIsDown;
};

#endif
