//	ShipBullet.cpp - Represents a bullet fired by the player's ship.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ShipBullet.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t ShipBullet::bullet1 = 0;
uint32_t ShipBullet::bullet2 = 0;
uint32_t ShipBullet::bullet3 = 0;
uint32_t ShipBullet::bullet4 = 0;

//------------------------------------------------------------------------------
ShipBullet::ShipBullet(float x, float y, bool e):
xPos(x),
yPos(y),
enemy(e),
bulletAnim(0)
{
	
}

//------------------------------------------------------------------------------
ShipBullet::~ShipBullet()
{
	
}

//------------------------------------------------------------------------------
bool ShipBullet::move()
{
	bool retval = false;

	if(!enemy)
	{
		yPos -= 2.0f;
		if(yPos < -16.0f)
			retval = true;
	}
	else
	{
		yPos += 2.0f;
		if(yPos > 320.0f)
			retval = true;
	}

	if(bulletAnim < AnimLength)
		++bulletAnim;

	return retval;
}

//------------------------------------------------------------------------------
void ShipBullet::draw(Drawer *d)
{
	if(!bullet1)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::bullet1_png, Images::bullet1_pngSize);
		bullet1 = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::bullet2_png, Images::bullet2_pngSize);
		bullet2 = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::bullet3_png, Images::bullet3_pngSize);
		bullet3 = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::bullet4_png, Images::bullet4_pngSize);
		bullet4 = d->loadImage(data.data, data.width, data.height);
	}

	if(!enemy)
	{
		if(bulletAnim < (AnimLength/4))
			d->drawImage(bullet1, xPos, yPos);
		else if(bulletAnim < (2*(AnimLength/4)))
			d->drawImage(bullet2, xPos, yPos);
		else if(bulletAnim < (3*(AnimLength/4)))
			d->drawImage(bullet3, xPos, yPos);
		else
			d->drawImage(bullet4, xPos, yPos);
	}
	else
	{
		if(bulletAnim < (AnimLength/4))
			d->drawImage(bullet1, xPos, yPos, 1.0f, -1.0f, 1.0f, 0.0f, 0.0f);
		else if(bulletAnim < (2*(AnimLength/4)))
			d->drawImage(bullet2, xPos, yPos, 1.0f, -1.0f, 1.0f, 0.0f, 0.0f);
		else if(bulletAnim < (3*(AnimLength/4)))
			d->drawImage(bullet3, xPos, yPos, 1.0f, -1.0f, 1.0f, 0.0f, 0.0f);
		else
			d->drawImage(bullet4, xPos, yPos, 1.0f, -1.0f, 1.0f, 0.0f, 0.0f);
	}
}
