//	ShipBullet.h - Represents a bullet fired by the player's ship.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SHIPBULLET_H_
#define SHIPBULLET_H_

#include <stdint.h>

class Drawer;

///	Represents a bullet fired by the player's ship.
class ShipBullet
{
  public:
	///	Constructor.
	ShipBullet(float x, float y, bool e = false);
	///	Destructor.
	~ShipBullet();

	///	Moves the bullet.
	/*!
		\return True if it's time to delete the bullet.
	 */
	bool move();
	///	Draws the bullet.
	void draw(Drawer *d);

	///	Returns the bullet's position.
	float getX() const {return xPos;};
	///	Returns the bullet's position.
	float getY() const {return yPos;};
	///	Returns whether this bullet was fired by an enemy.
	bool getEnemy() const {return enemy;};
  private:
	///	Constant used by the bullet animation.
	enum
	{
		AnimLength = 8
	};

	///	The bullet's image.
	static uint32_t bullet1;
	///	The bullet's image.
	static uint32_t bullet2;
	///	The bullet's image.
	static uint32_t bullet3;
	///	The bullet's image.
	static uint32_t bullet4;

	///	The bullet's position.
	float xPos;
	///	The bullet's position.
	float yPos;
	///	If this bullet was fired by an enemy.
	bool enemy;

	///	Used to animate the bullet slightly.
	int bulletAnim;
};

#endif
