//	ShooterEnemy.cpp - Enemy ship for the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ShooterEnemy.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "Random.h"

//------------------------------------------------------------------------------
uint32_t ShooterEnemy::image = 0;

//------------------------------------------------------------------------------
ShooterEnemy::ShooterEnemy():
warping(true),
warpTimer(90),
lives(4)
{
	xPos = Random::getGlobal().getRandomFloat() * (224.0f-32.0f);
	yPos = 32.0f + (Random::getGlobal().getRandomFloat() * 32.0f);
	dir = (Random::getGlobal().getRandomFloat() - 0.5f) * 2.0f;
	if((dir < 0.0f) && (dir > - 0.5f))
		dir -= 0.5f;
	else if((dir >= 0.0f) && (dir < 0.5f))
		dir += 0.5f;
	bulletTimer = 120 + (int)(Random::getGlobal().getRandomFloat() * 120.0f);
}

//------------------------------------------------------------------------------
ShooterEnemy::~ShooterEnemy()
{
	
}

//------------------------------------------------------------------------------
bool ShooterEnemy::move()
{
	bool retval = false;

	if(warping)
	{
		--warpTimer;
		if(warpTimer <= 0)
			warping = false;
	}
	else
	{
		xPos += dir;
		if(xPos < 0.0f)
			dir = Random::getGlobal().getRandomFloat();
		else if(xPos >= (224.0f-32.0f))
			dir = -Random::getGlobal().getRandomFloat();

		if((dir < 0.0f) && (dir > - 0.5f))
			dir -= 0.5f;
		else if((dir >= 0.0f) && (dir < 0.5f))
			dir += 0.5f;

		--bulletTimer;
		if(!bulletTimer)
		{
			bulletTimer = 120 + (int)(Random::getGlobal().getRandomFloat() * 120.0f);
			retval = true;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void ShooterEnemy::draw(Drawer *d)
{
	float x, y;
	float height;
	float flash = 1.0f;
	float alpha = 1.0f;

	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::shooterenemy_png, Images::shooterenemy_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	//Work out the position to draw it at.
	x = xPos;
	if(warping)
	{
		alpha = 0.5f;
		if(warpTimer > 60)
		{
			height = 96.0f;
			y = yPos*(1.0f - ((float)(warpTimer-60)/30.0f));
			y -= (height-32.0f);
		}
		else
		{
			height = 32.0f + (((float)warpTimer/60.0f) * 64.0f);
			y = yPos - (height-32.0f);
		}
	}
	else
	{
		height = 32.0f;
		y = yPos;

		if(bulletTimer < 15)
			flash = (float)bulletTimer/15.0f;
	}

	d->drawImage(image, x, y, 1.0f, (height/32.0f), 1.0f, flash, flash, alpha);
}

//------------------------------------------------------------------------------
bool ShooterEnemy::decrementLives(int val)
{
	bool retval = false;

	lives -= val;
	if(lives < 0)
		retval = true;

	return retval;
}
