//	ShooterEnemy.h - Enemy ship for the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SHOOTERENEMY_H_
#define SHOOTERENEMY_H_

#include <stdint.h>

class Drawer;

///	Enemy ship for the shooter section.
class ShooterEnemy
{
  public:
	///	Constructor.
	ShooterEnemy();
	///	Destructor.
	~ShooterEnemy();

	///	Moves the enemy, returns true if it's time to fire a bullet.
	bool move();
	///	Draws the enemy.
	void draw(Drawer *d);

	///	Decrements the enemy's lives, returns true when they're dead.
	bool decrementLives(int val = 1);

	///	Returns the enemy's position.
	float getX() const {return xPos;};
	///	Returns the enemy's position.
	float getY() const {return yPos;};
	///	Returns true if the enemy is still warping in.
	bool isWarping() const {return warping;};
  private:
	///	The enemy image.
	static uint32_t image;

	///	The enemy's position.
	float xPos;
	///	The enemy's position.
	float yPos;
	///	Which (x-axis) direction the enemy's moving towards.
	float dir;
	///	Whether the enemy's still warping in or not.
	bool warping;
	///	Used to warp the enemy in.
	int warpTimer;
	///	Used to fire a new bullet.
	int bulletTimer;
	///	The enemy's lives.
	int lives;
};

#endif
