//	ShooterTile.cpp - A tile in the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ShooterTile.h"
#include "NiallsDrawingLib/Drawer.h"
#include "Random.h"

#include <cmath>

//------------------------------------------------------------------------------
ShooterTile::ShooterTile(uint32_t im, int i, float s):
image(im),
index(i),
scale(s),
xDest(0.0f),
yDest(0.0f),
moving(true),
movingFinal(false)
{
	xPos = 32.0f + (Random::getGlobal().getRandomFloat() * (224.0f-96.0f));
	yPos = -32.0f;

	speed = (Random::getGlobal().getRandomFloat() * 0.4f) + 0.8f;
	if(xPos < 112.0f)
		xSpeed = -(((112.0f - xPos)/112.0f) * 0.2f);
	else if(xPos > 112.0f)
		xSpeed = ((xPos - 112.0f)/112.0f) * 0.2f;
	else
		xSpeed = 0.0f;
}

//------------------------------------------------------------------------------
ShooterTile::~ShooterTile()
{
	
}

//------------------------------------------------------------------------------
bool ShooterTile::move()
{
	bool retval = false;

	if(moving)
	{
		yPos += speed;
		xPos += xSpeed;

		if(yPos > 320.0f)
			retval = true;
	}
	else if(movingFinal)
	{
		xPos += ((xDest - xPos)*0.125f);
		yPos += ((yDest - yPos)*0.125f);

		if((fabsf(xPos-xDest) < 1.0f) && (fabsf(yPos-yDest) < 1.0f))
		{
			xPos = xDest;
			yPos = yDest;
			movingFinal = false;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void ShooterTile::draw(Drawer *d)
{
	if(moving)
	{
		if(index < 64)
			d->fillRect(xPos-2.0f, yPos-2.0f, 36, 36, 0, 0, 0, 255);
		else if(index < 128)
			d->fillRect(xPos-2.0f, yPos-2.0f, 36, 36, 255, 255, 0, 255);
		else if(index < 192)
			d->fillRect(xPos-2.0f, yPos-2.0f, 36, 36, 255, 0, 0, 255);
	}
	d->drawImage(image, xPos, yPos, scale, scale);
}

//------------------------------------------------------------------------------
void ShooterTile::moveTo(int x, int y)
{
	xDest = x;
	yDest = y;
	moving = false;
	movingFinal = true;
}
