//	ShooterTile.h - A tile in the shooter section.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SHOOTERTILE_H_
#define SHOOTERTILE_H_

#include <stdint.h>

class Drawer;

///	A tile in the shooter section.
class ShooterTile
{
  public:
	///	Constructor.
	ShooterTile(uint32_t im, int i, float s);
	///	Destructor.
	~ShooterTile();

	///	Moves the tile.
	bool move();
	///	Draws the tile.
	void draw(Drawer *d);

	///	Returns true if the tile's in motion.
	bool isMoving() const {return moving;};
	///	Called when the player shoots the tile, to move it to the correct position.
	void moveTo(int x, int y);

	///	Returns the tile's index.
	int getIndex() const {return index;};
	///	Returns the tile's position.
	float getX() const {return xPos;};
	///	Returns the tile's position.
	float getY() const {return yPos;};
  private:
	///	The tile's image.
	uint32_t image;
	///	The tile's index.
	int index;
	///	The scale to draw the tile at.
	float scale;

	///	The tile's position.
	float xPos;
	///	The tile's position.
	float yPos;
	///	The tile's speed.
	float speed;
	///	The tile's x-axis speed.
	float xSpeed;

	///	The tile's destination.
	float xDest;
	///	The tile's destination.
	float yDest;

	///	Whether the tile's currently moving or not.
	bool moving;
	///	Whether the tile's moving to its final position.
	bool movingFinal;
};

#endif
