//	Skeleton.cpp - Bad guy for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Skeleton.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t Skeleton::up[3] = {0, 0, 0};
uint32_t Skeleton::right[3] = {0, 0, 0};
uint32_t Skeleton::down[3] = {0, 0, 0};

//------------------------------------------------------------------------------
Skeleton::Skeleton(float x, float y):
xPos(x),
yPos(y),
health(8),
image(0),
frame(0),
prevFrame(0),
animTimer(15)
{
	
}

//------------------------------------------------------------------------------
Skeleton::~Skeleton()
{
	
}

//------------------------------------------------------------------------------
void Skeleton::move(uint8_t *map, int width, int height, float pX, float pY)
{
	int x, y;
	int x2, y2;
	float xRes, yRes;
	float xDir, yDir;

	//Try and move towards the player.
	if(yPos >= 0.0f)
	{
		if(pX > (xPos+16.0f))
			xDir = 0.5f;
		else if(pX < (xPos+16.0f))
			xDir = -0.5f;
		else
			xDir = 0.0f;
	}
	else
		xDir = 0.0f;
	if(pY > (yPos+16.0f))
		yDir = 0.5f;
	else if(pY < (yPos+16.0f))
		yDir = -0.5f;
	else
		yDir = 0.0f;

	if(yDir < 0.0f)
		image = 0;
	else if(yDir > 0.0f)
		image = 2;
	else if(xDir > 0.0f)
		image = 1;
	else if(xDir < 0.0f)
		image = 3;

	xRes = xPos + xDir;
	yRes = yPos + yDir;

	//Collide with the walls.
	x = xRes/32;
	y = yRes/32;
	x2 = (xRes+16.0f)/32;
	if(x2 >= width)
		x2 = width-1;
	y2 = (yRes+24.0f)/32;
	if(y2 >= height)
		y2 = height-1;

	if((xDir != 0.0f)  || (yDir != 0.0f))
	{
		if(xDir < 0.0f)
		{
			if(((map[(y*width)+x] > 63) && (map[(y*width)+x] != 192)) ||
			   ((map[(y2*width)+x] > 63) && (map[(y2*width)+x] != 192)))
			{
				if(yDir < 0.0f)
				{
					if((map[(y2*width)+x] < 64) || (map[(y2*width)+x] == 192))
						yRes = yPos;
					else if((map[(y*width)+x2] < 64) || (map[(y*width)+x2] == 192))
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else if(yDir > 0.0f)
				{
					if((map[(y*width)+x] < 64) || (map[(y*width)+x] == 192))
						yRes = yPos;
					else if((map[(y2*width)+x2] < 64) || (map[(y2*width)+x2] == 192))
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else
					xRes = xPos;
			}
		}
		else if(xDir > 0.0f)
		{
			if(((map[(y*width)+x2] > 63) && (map[(y*width)+x2] < 192)) ||
			   ((map[(y2*width)+x2] > 63) && (map[(y2*width)+x2] < 192)))
			{
				if(yDir < 0.0f)
				{
					if((map[(y2*width)+x2] < 64) || (map[(y2*width)+x2] == 192))
						yRes = yPos;
					else if((map[(y*width)+x] < 64) || (map[(y*width)+x] == 192))
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else if(yDir > 0.0f)
				{
					if((map[(y*width)+x2] < 64) || (map[(y*width)+x2] == 192))
						yRes = yPos;
					else if((map[(y2*width)+x] < 64) || (map[(y2*width)+x] == 192))
						xRes = xPos;
					else
					{
						xRes = xPos;
						yRes = yPos;
					}
				}
				else
					xRes = xPos;
			}
		}
		else if(yDir < 0.0f)
		{
			if(((map[(y*width)+x] > 63) && (map[(y*width)+x] < 192)) ||
			   ((map[(y*width)+x2] > 63) && (map[(y*width)+x2] < 192)))
			{
				yRes = yPos;
			}
		}
		else if(yDir > 0.0f)
		{
			if(((map[(y2*width)+x] > 63) && (map[(y2*width)+x] < 192)) ||
			   ((map[(y2*width)+x2] > 63) && (map[(y2*width)+x2] < 192)))
			{
				yRes = yPos;
			}
		}
	}

	xPos = xRes;
	yPos = yRes;

	//Update the animation variables.
	--animTimer;
	if(animTimer == 0)
	{
		animTimer = 10;
		/*if((image == 0) || (image == 2))
		{
			prevFrame = frame;
			frame = (frame+1)%2;
		}
		else*/
		{
			if(frame > -1)
				frame = -1;
			else if(prevFrame == 0)
			{
				frame = 1;
				prevFrame = frame;
			}
			else
			{
				frame = 0;
				prevFrame = frame;
			}
		}
	}
}

//------------------------------------------------------------------------------
void Skeleton::draw(Drawer *d)
{
	if(!up[0])
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::skeletonup1_png, Images::skeletonup1_pngSize);
		up[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletonup2_png, Images::skeletonup2_pngSize);
		up[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletonup3_png, Images::skeletonup3_pngSize);
		up[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletonright1_png, Images::skeletonright1_pngSize);
		right[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletonright2_png, Images::skeletonright2_pngSize);
		right[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletonright3_png, Images::skeletonright3_pngSize);
		right[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletondown1_png, Images::skeletondown1_pngSize);
		down[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletondown2_png, Images::skeletondown2_pngSize);
		down[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::skeletondown3_png, Images::skeletondown3_pngSize);
		down[2] = d->loadImage(data.data, data.width, data.height);
	}

	switch(image)
	{
		case 0: //Up.
			d->drawImage(up[frame+1], xPos, yPos);
			break;
		case 1: //Right.
			d->drawImage(right[frame+1], xPos, yPos);
			break;
		case 2: //Down.
			d->drawImage(down[frame+1], xPos, yPos);
			break;
		case 3: //Left.
			d->drawImage(right[frame+1], xPos+16, yPos, -1.0f);
			break;
	}
}

//------------------------------------------------------------------------------
bool Skeleton::decrementHealth(int val)
{
	bool retval = false;

	health -= val;
	if(health <= 0)
		retval = true;

	return retval;
}

//------------------------------------------------------------------------------
bool Skeleton::findPlayer(int& score,
						  int tX,
						  int tY,
						  int prevX,
						  int prevY,
						  uint8_t *map,
						  int width,
						  int height,
						  int pX,
						  int pY)
{
	int i;
	int x, y;
	bool retval = false;

	++score;

	if((pX == tX) && (pY == tY))
		retval = true;
	else if(map[(tY*width)+tX] > 63)
		retval = false;
	else if(score > 50) //To make sure we don't get too many recursions?
		retval = false;
	else
	{
		int lowest = 50;
		int tempScores[8] = {score, 50, score, 50, score, 50, score, 50};

		//Try straight up.
		if(tY > 0)
		{
			x = tX;
			y = tY-1;
			retval = findPlayer(tempScores[0],
								x,
								y,
								tX,
								tY,
								map,
								width,
								height,
								pX,
								pY);
		}
		else
			tempScores[0] = 50;
		//Try right.
		if((tX < (width-1)) && !retval)
		{
			x = tX+1;
			y = tY;
			retval = findPlayer(tempScores[2],
								x,
								y,
								tX,
								tY,
								map,
								width,
								height,
								pX,
								pY);
		}
		else
			tempScores[2] = 50;
		//Try down.
		if((tY < (height-1)) && !retval)
		{
			x = tX;
			y = tY+1;
			retval = findPlayer(tempScores[4],
								x,
								y,
								tX,
								tY,
								map,
								width,
								height,
								pX,
								pY);
		}
		else
			tempScores[4] = 50;
		//Try left.
		if((tX > 0) && !retval)
		{
			x = tX-1;
			y = tY;
			retval = findPlayer(tempScores[6],
								x,
								y,
								tX,
								tY,
								map,
								width,
								height,
								pX,
								pY);
		}
		else
			tempScores[6] = 50;

		for(i=0;i<8;++i)
		{
			if(tempScores[i] < lowest)
				lowest = tempScores[i];
		}

		score += lowest;
	}

	return retval;
}
