//	Skeleton.h - Bad guy for the gauntlet stage.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SKELETON_H_
#define SKELETON_H_

#include <stdint.h>

class Drawer;

///	Bad guy for the gauntlet stage.
class Skeleton
{
  public:
	///	Constructor.
	Skeleton(float x, float y);
	///	Destructor.
	~Skeleton();

	///	Moves the skeleton.
	void move(uint8_t *map, int width, int height, float pX, float pY);
	///	Draws the skeleton.
	void draw(Drawer *d);

	///	Decrement the skeleton's health, returns true if the skeleton died.
	bool decrementHealth(int val);

	///	Returns the Skeleton's position.
	float getX() const {return xPos;};
	///	Returns the Skeleton's position.
	float getY() const {return yPos;};
  private:
	///	Recursive method used to find the player.
	bool findPlayer(int& score,
					int tX,
					int tY,
					int prevX,
					int prevY,
					uint8_t *map,
					int width,
					int height,
					int pX,
					int pY);

	///	The Skeleton's upwards images.
	static uint32_t up[3];
	///	The Skeleton's rightwards images.
	static uint32_t right[3];
	///	The Skeleton's downwards images.
	static uint32_t down[3];

	///	The Skeleton's position.
	float xPos;
	///	The Skeleton's position.
	float yPos;
	///	The skeleton's health.
	int health;

	///	Which set of images to use.
	int image;
	///	Which animation frame we're on.
	int frame;
	///	The previous animation frame.
	int prevFrame;
	///	Used to time the animations correctly.
	int animTimer;
};

#endif
