//	TileSet.h - Base class for a tile set.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TILESET_H_
#define TILESET_H_

#include <string>
#include <stdint.h>

class Drawer;

///	Base class for a tile set.
class TileSet
{
  public:
	///	Constructor.
	TileSet() {};
	///	Destructor.
	virtual ~TileSet() {};

	///	Loads the tiles in this set.
	virtual void loadTiles(Drawer *d) = 0;

	///	Returns the number of ground tiles in this set.
	virtual int getNumGroundTiles() const = 0;
	///	Returns the number of destructable tiles in this set.
	virtual int getNumWallTiles() const = 0;
	///	Returns the number of impassable tiles in this set.
	virtual int getNumImpassableTiles() const = 0;

	///	Returns the size of the tiles (tiles are assumed to be square).
	virtual int getTileSize() const = 0;
	///	Returns the tileset's author.
	virtual std::string getAuthor() const = 0;

	///	Returns the indexed ground tile.
	virtual uint32_t getGroundTile(int i) = 0;
	///	Returns the indexed destructable tile.
	virtual uint32_t getWallTile(int i) = 0;
	///	Returns the indexed impassable tile.
	virtual uint32_t getImpassableTile(int i) = 0;
};

#endif
