//	TileSetFactory.cpp - Singleton used to provide TileSets.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "TileSetFactory.h"

#include "AcidTileSet.h"
#include "Dbb1TileSet.h"
#include "Dbb2TileSet.h"
#include "NiallMTileSet.h"
#include "Tocky1TileSet.h"
#include "Tocky2TileSet.h"
#include "BigLonTileSet.h"
#include "OverkillTileSet.h"

//------------------------------------------------------------------------------
TileSetFactory& TileSetFactory::getInstance()
{
	static TileSetFactory retval;

	return retval;
}

//------------------------------------------------------------------------------
void TileSetFactory::addTileSet(TileSet *set)
{
	tileSets.push_back(set);
}

//------------------------------------------------------------------------------
void TileSetFactory::loadTiles(Drawer *d)
{
	int i;

	for(i=0;i<tileSets.size();++i)
		tileSets[i]->loadTiles(d);
}

//------------------------------------------------------------------------------
TileSetFactory::TileSetFactory()
{
	tileSets.push_back(new AcidTileSet());
	tileSets.push_back(new Tocky2TileSet());
	tileSets.push_back(new OverkillTileSet());
	tileSets.push_back(new BigLonTileSet());
	tileSets.push_back(new Dbb1TileSet());
	tileSets.push_back(new Dbb2TileSet());
	tileSets.push_back(new Tocky1TileSet());
	tileSets.push_back(new NiallMTileSet());
}

//------------------------------------------------------------------------------
TileSetFactory::~TileSetFactory()
{
	
}
