//	TileSetFactory.h - Singleton used to provide TileSets.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TILESETFACTORY_H_
#define TILESETFACTORY_H_

#include <vector>

class Drawer;
class TileSet;

///	Singleton used to provide TileSets.
class TileSetFactory
{
  public:
	///	Returns the sole instance of the factory.
	static TileSetFactory& getInstance();

	///	Adds a TileSet to the list.
	void addTileSet(TileSet *set);
	///	Loads all the available TileSets onto the graphics card.
	void loadTiles(Drawer *d);

	///	Returns the number of available TileSets.
	int getNumTileSets() const {return tileSets.size();};
	///	Returns the indexed TileSet.
	TileSet *getTileSet(int i) {return tileSets[i];};

#ifdef WIN32
	///	Destructor.
	~TileSetFactory();
#endif
  private:
	///	Constructor.
	TileSetFactory();
#ifndef WIN32
	///	Destructor.
	~TileSetFactory();
#endif

	///	The available TileSets.
	std::vector<TileSet *> tileSets;
};

#endif
