//	WinScreen.cpp - The win screen game state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "WinScreen.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "GameCounter.h"

using namespace std;

//------------------------------------------------------------------------------
uint32_t WinScreen::background = 0;

//------------------------------------------------------------------------------
WinScreen::WinScreen(Application *app, int *scores, string *names):
GameState(app),
highScores(scores),
highScoreNames(names)
{
	
}

//------------------------------------------------------------------------------
WinScreen::~WinScreen()
{
	
}

//------------------------------------------------------------------------------
void WinScreen::draw(Drawer *d)
{
	if(!background)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::win_png, Images::win_pngSize);
		background = d->loadImage(data.data, data.width, data.height);
	}

	d->drawImage(background, -8, 0);

	if(GameCounter::getInstance().getScore() > highScores[5])
	{
		d->drawText("you got high score", 20, 240, 16.0f);
		d->drawText("enter initials", 40, 256, 16.0f);
		d->drawText(initials.str(), 80, 280, 32.0f);
	}
}

//------------------------------------------------------------------------------
void WinScreen::keyDown(const SDL_keysym& keyPressed)
{
	int i;

	if(GameCounter::getInstance().getScore() < highScores[5])
	{
		if((keyPressed.sym == SDLK_z) || (keyPressed.sym == SDLK_ESCAPE))
			nextState("TitleScreen");
	}
	else if(initials.str().length() < 3)
	{
		if(keyPressed.sym == SDLK_BACKSPACE)
		{
			string tempstr = initials.str().substr(0, initials.str().length()-1);

			initials.str(tempstr);
		}
		else if(keyPressed.sym == SDLK_RETURN)
		{
			while(initials.str().length() < 3)
				initials << " ";
		}
		else if(isValidChar(keyPressed.sym))
			initials << getChar(keyPressed.sym);

		if(initials.str().length() == 3)
		{
			int tempint = GameCounter::getInstance().getScore();
			string tempstr = initials.str();

			if(tempint > highScores[5])
			{
				highScores[5] = tempint;
				highScoreNames[5] = tempstr;
			}
			for(i=5;i>0;--i)
			{
				if(highScores[i] > highScores[i-1])
				{
					tempint = highScores[i-1];
					tempstr = highScoreNames[i-1];
					highScores[i-1] = highScores[i];
					highScoreNames[i-1] = highScoreNames[i];
					highScores[i] = tempint;
					highScoreNames[i] = tempstr;
				}
			}

			nextState("TitleScreen");
		}
	}
	else
		nextState("TitleScreen");
}

//------------------------------------------------------------------------------
bool WinScreen::isValidChar(SDLKey sym) const
{
	bool retval = false;

	switch(sym)
	{
		case SDLK_0:
		case SDLK_1:
		case SDLK_2:
		case SDLK_3:
		case SDLK_4:
		case SDLK_5:
		case SDLK_6:
		case SDLK_7:
		case SDLK_8:
		case SDLK_9:
		case SDLK_a:
		case SDLK_b:
		case SDLK_c:
		case SDLK_d:
		case SDLK_e:
		case SDLK_f:
		case SDLK_g:
		case SDLK_h:
		case SDLK_i:
		case SDLK_j:
		case SDLK_k:
		case SDLK_l:
		case SDLK_m:
		case SDLK_n:
		case SDLK_o:
		case SDLK_p:
		case SDLK_q:
		case SDLK_r:
		case SDLK_s:
		case SDLK_t:
		case SDLK_u:
		case SDLK_v:
		case SDLK_w:
		case SDLK_x:
		case SDLK_y:
		case SDLK_z:
		case SDLK_PERIOD:
			retval = true;
	}

	return retval;
}

//------------------------------------------------------------------------------
char WinScreen::getChar(SDLKey sym) const
{
	char retval = '0';

	switch(sym)
	{
		case SDLK_0:
			retval = '0';
			break;
		case SDLK_1:
			retval = '1';
			break;
		case SDLK_2:
			retval = '2';
			break;
		case SDLK_3:
			retval = '3';
			break;
		case SDLK_4:
			retval = '4';
			break;
		case SDLK_5:
			retval = '5';
			break;
		case SDLK_6:
			retval = '6';
			break;
		case SDLK_7:
			retval = '7';
			break;
		case SDLK_8:
			retval = '8';
			break;
		case SDLK_9:
			retval = '9';
			break;
		case SDLK_a:
			retval = 'a';
			break;
		case SDLK_b:
			retval = 'b';
			break;
		case SDLK_c:
			retval = 'c';
			break;
		case SDLK_d:
			retval = 'd';
			break;
		case SDLK_e:
			retval = 'e';
			break;
		case SDLK_f:
			retval = 'f';
			break;
		case SDLK_g:
			retval = 'g';
			break;
		case SDLK_h:
			retval = 'h';
			break;
		case SDLK_i:
			retval = 'i';
			break;
		case SDLK_j:
			retval = 'j';
			break;
		case SDLK_k:
			retval = 'k';
			break;
		case SDLK_l:
			retval = 'l';
			break;
		case SDLK_m:
			retval = 'm';
			break;
		case SDLK_n:
			retval = 'n';
			break;
		case SDLK_o:
			retval = 'o';
			break;
		case SDLK_p:
			retval = 'p';
			break;
		case SDLK_q:
			retval = 'q';
			break;
		case SDLK_r:
			retval = 'r';
			break;
		case SDLK_s:
			retval = 's';
			break;
		case SDLK_t:
			retval = 't';
			break;
		case SDLK_u:
			retval = 'u';
			break;
		case SDLK_v:
			retval = 'v';
			break;
		case SDLK_w:
			retval = 'w';
			break;
		case SDLK_x:
			retval = 'x';
			break;
		case SDLK_y:
			retval = 'y';
			break;
		case SDLK_z:
			retval = 'z';
			break;
		case SDLK_PERIOD:
			retval = '.';
			break;
	}

	return retval;
}