//	TwoFloats.h - Simple struct containing three floats.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2009  Niall Moody
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//	----------------------------------------------------------------------------

#ifndef TWOFLOATS_H_
#define TWOFLOATS_H_

#include <cmath>

///	Simple struct containing two floats.
struct TwoFloats
{
	float x;
	float y;

	///	Default constructor.
	TwoFloats()
	{
		x = y = 0.0f;
	}

	///	Constructor, all members set to val.
	TwoFloats(float val)
	{
		x = y = val;
	}

	///	Constructor.
	TwoFloats(float xVal, float yVal)
	{
		x = xVal;
		y = yVal;
	}

	///	Assignment operator.
	TwoFloats& operator=(const TwoFloats& op2)
	{
		x = op2.x;
		y = op2.y;
		return *this;
	}

	///	Assignment operator (assigns all members the value of val).
	TwoFloats& operator=(float val)
	{
		x = val;
		y = val;
		return *this;
	}

	///	Addition operator.
	TwoFloats operator+(const TwoFloats& op2)
	{
		TwoFloats retval;

		retval.x = x + op2.x;
		retval.y = y + op2.y;

		return retval;
	}

	///	Subtraction operator.
	TwoFloats operator-(const TwoFloats& op2)
	{
		TwoFloats retval;

		retval.x = x - op2.x;
		retval.y = y - op2.y;

		return retval;
	}

	///	Multiplication operator.
	TwoFloats operator*(const TwoFloats& op2)
	{
		TwoFloats retval;

		retval.x = x * op2.x;
		retval.y = y * op2.y;

		return retval;
	}

	///	Multiplication operator (float).
	TwoFloats operator*(float val)
	{
		TwoFloats retval;

		retval.x = x * val;
		retval.y = y * val;

		return retval;
	}

	///	Addition assignment operator.
	TwoFloats& operator+=(const TwoFloats& op2)
	{
		x += op2.x;
		y += op2.y;

		return *this;
	}

	///	Subtraction assignment operator.
	TwoFloats& operator-=(const TwoFloats& op2)
	{
		x -= op2.x;
		y -= op2.y;

		return *this;
	}

	///	Multiplication assignment operator.
	TwoFloats& operator*=(const TwoFloats& op2)
	{
		x *= op2.x;
		y *= op2.y;

		return *this;
	}

	///	Multiplication assignment operator.
	TwoFloats& operator*=(float op2)
	{
		x *= op2;
		y *= op2;

		return *this;
	}

	///	Equality operator.
	bool operator==(const TwoFloats& op2)
	{
		return (x==op2.x)&&(y==op2.y);
	}

	///	Inequality operator.
	bool operator!=(const TwoFloats& op2)
	{
		return (x!=op2.x)||(y!=op2.y);
	}

	///	Returns the distance between two TwoFloats.
	float getDistance(const TwoFloats& op2) const
	{
		float tempX = op2.x - x;
		float tempY = op2.y - y;

		return sqrtf((tempX*tempX) + (tempY*tempY));
	}

	friend TwoFloats operator*(float op1, const TwoFloats& op2);
};

#endif
