//	FailScreen.h - The fail screen game state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FAILSCREEN_H_
#define FAILSCREEN_H_

#include "GameState.h"

#include <sstream>
#include <stdint.h>

///	The title screen game state.
class FailScreen : public GameState
{
  public:
	///	Constructor.
	FailScreen(Application *app, int *scores, std::string *names);
	///	Destructor.
	~FailScreen();

	///	Draws the title screen.
	void draw(Drawer *d);

	///	Used to cycle through the button states.
	void keyDown(const SDL_keysym& keyPressed);

	///	Returns the name of this state.
	const std::string getName() const {return "FailScreen";};
  private:
	///	Helper method to check whether an SDL sym is a valid path character.
	bool isValidChar(SDLKey sym) const;
	///	Helper method to convert an SDL sym into an ascii char.
	char getChar(SDLKey sym) const;

	///	The id of the background to draw.
	static uint32_t background;

	///	The high scores.
	int *highScores;
	///	The high score names.
	std::string *highScoreNames;

	///	Used to let the player enter their initials.
	std::stringstream initials;
};

#endif
