//	GauntletGamePlay.h - The gauntlet state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GAUNTLETGAMEPLAY_H_
#define GAUNTLETGAMEPLAY_H_

#include "GameState.h"
#include "GauntletPlayer.h"
#include "ParticleGenerator.h"

#include <vector>

class Pickup;
class TileSet;
class Skeleton;
class Explosion;
class TextScroller;
class EnemySpawner;
class GauntletBullet;

///	The gauntlet state.
class GauntletGamePlay : public GameState
{
  public:
	///	Constructor.
	GauntletGamePlay(Application *app, uint8_t *level, TileSet *tiles, int index);
	///	Destructor.
	~GauntletGamePlay();

	///	Draws the title screen.
	void draw(Drawer *d);

	///	Used to move the ship and fire.
	void keyDown(const SDL_keysym& keyPressed);
	///	Used to move the ship and fire.
	void keyUp(const SDL_keysym& keyPressed);

	///	Returns the name of this state.
	const std::string getName() const {return "GauntletGamePlay";};
  private:
	///	Helper method to work out when a bullet's collided with something.
	void bulletCollisions();
	///	Helper method to work out when a skeleton's collided with the player.
	void playerCollisions();
	///	Helper method to work out when the player's collided with a pickup.
	void pickupCollisions();

	///	The size of the map.
	enum
	{
		MapWidth = 7,
		MapHeight = 10,

		NumParticles = 64
	};

	///	The lives heart image.
	static uint32_t heartImage;
	///	The arrow pointing to the level exit.
	static uint32_t exitArrow;
	///	Spark particle 1.
	static uint32_t particle1;
	///	Spark particle 2.
	static uint32_t particle2;

	///	The level.
	uint8_t map[MapWidth*MapHeight];
	///	Used to destroy walls when they've been hit enough times.
	uint8_t walls[MapWidth*MapHeight];
	///	The tileset we're using.
	TileSet *tileSet;

	///	Used to display tutorial text.
	TextScroller *tutorial;

	///	The player character.
	GauntletPlayer player;
	///	The player's bullets active on the level.
	std::vector<GauntletBullet *> bullets;
	///	The enemy spawners on the level.
	std::vector<EnemySpawner *> spawners;
	///	The skeletons on the level.
	std::vector<Skeleton *> skeletons;
	///	Any explosions active on the level.
	std::vector<Explosion *> explosions;
	///	Any pickups on the level.
	std::vector<Pickup *> pickups;
	///	The available particle generators.
	ParticleGenerator particles[NumParticles];

	///	Used to bounce the exit arrow.
	float arrowBounce;

	///	Used to fire bullets from the player.
	bool fireIsDown;
	///	Used to fire bullets from the player.
	int bulletTimer;
	///	Used to work out if the player deserves the pacifist bonus.
	bool pacifist;

	///	Used to spawn skeletons from the top of the screen.
	int skeletonTimer;

	///	If the player is killed before they reach the exit.
	bool gameOver;
	///	If the player's got to the top of the level.
	bool levelComplete;

	///	If we're paused.
	bool paused;
};

#endif
