//	LevelEditor.h - The level editor state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef LEVELEDITOR_H_
#define LEVELEDITOR_H_

#include "GameState.h"

#include <sstream>

class TileSet;

///	The level editor state.
class LevelEditor : public GameState
{
  public:
	///	Constructor.
	LevelEditor(Application *app);
	///	Destructor.
	~LevelEditor();

	///	Draws the current state.
	void draw(Drawer *d);

	///	Called when a key down event is received.
	void keyDown(const SDL_keysym& keyPressed);

	///	Called when a mouse down event is received.
	void mouseDown(int button, int x, int y);
	///	Called when a mouse up event is received.
	void mouseUp(int button, int x, int y);
	///	Called when a mouse move event is received.
	void mouseMove(int x, int y);

	///	Loads the level with the passed-in name.
	void load(const std::string& path);

	///	Returns the name of this state.
	const std::string getName() const {return "LevelEditor";};
  private:
	///	Saves the current level.
	void save();

	///	Helper method to check whether an SDL sym is a valid path character.
	bool isValidChar(SDLKey sym) const;
	///	Helper method to convert an SDL sym into an ascii char.
	char getChar(SDLKey sym) const;

	///	The size of the map.
	enum
	{
		MapWidth = 7,
		MapHeight = 10
	};

	///	The mouse cursor.
	uint32_t mouse;

	///	The current tile set to use.
	TileSet *tileSet;

	///	The current map.
	/*!
		Tiles are stored by their indices, in 8 bits.  Values 0->63 are ground
		tiles, 64->127 are wall tiles, and 128->191 are impassable tiles.  Who
		knows what the rest are...
	 */
	uint8_t map[MapWidth*MapHeight];

	///	The mouse position.
	float xPos;
	///	The mouse position.
	float yPos;
	///	Used to let the user drag draw tiles.
	bool dragging;

	///	The currently-selected tile.
	int currentTile;

	///	True if the user is selecting a tile set.
	bool selectTileSet;
	///	True if the user is selecting a particular tile.
	bool selectTile;

	///	True if we're in save mode (get the user to type in a name).
	bool saveMode;
	///	The name of the level before save mode was activated
	/*!
		In case the user decides they don't want to save.
	 */
	std::string prevSaveName;
	///	The name of the level to be saved.
	std::stringstream saveName;
};

#endif
