//	ShooterGamePlay.h - The shooter state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef SHOOTERGAMEPLAY_H_
#define SHOOTERGAMEPLAY_H_

#include "GameState.h"
#include "PlayerShip.h"
#include "ParticleGenerator.h"

#include <vector>

class TileSet;
class Explosion;
class ShipBullet;
class ShooterTile;
class TextScroller;
class ShooterEnemy;

///	The shooter state.
class ShooterGamePlay : public GameState
{
  public:
	///	Constructor.
	ShooterGamePlay(Application *app, int index);
	///	Destructor.
	~ShooterGamePlay();

	///	Draws the title screen.
	void draw(Drawer *d);

	///	Used to move the ship and fire.
	void keyDown(const SDL_keysym& keyPressed);
	///	Used to move the ship and fire.
	void keyUp(const SDL_keysym& keyPressed);

	///	Returns the name of this state.
	const std::string getName() const {return "ShooterGamePlay";};
  private:
	///	Helper method to collide bullets with tiles.
	void collideTiles();
	///	Helper method to collide the player with the tiles.
	void collidePlayer();

	///	Helper method to load the level.
	void load();

	///	The size of the map.
	enum
	{
		MapWidth = 7,
		MapHeight = 10,

		NumParticles = 64
	};

	///	The lives heart image.
	static uint32_t heartImage;
	///	The enemy spawner image.
	static uint32_t enemySpawnerImage;
	///	Particle image.
	static uint32_t particle1;
	///	Particle image.
	static uint32_t particle2;

	///	The player's ship.
	PlayerShip player;

	///	The available particle generators.
	ParticleGenerator particles[NumParticles];
	///	Used to display tutorial text.
	TextScroller *tutorial;

	///	Whether the player's holding down the fire key.
	bool fireIsDown;

	///	True when the player's completed the level.
	bool levelComplete;
	///	True if the player's lost all their lives.
	bool gameOver;

	///	If we're paused.
	bool paused;

	///	The bullets currently in play.
	std::vector<ShipBullet *> bullets;
	///	Used to ensure the player can only fire at or below a particular rate.
	int bulletRate;

	///	Which tile the player is currently shooting for.
	int currentTile;
	///	Used to flash the currentTile.
	float currentFlash;

	///	The current tile set to use.
	TileSet *tileSet;
	///	The current map.
	/*!
		Tiles are stored by their indices, in 8 bits.  Values 0->63 are ground
		tiles, 64->127 are wall tiles, and 128->191 are impassable tiles.  Who
		knows what the rest are...
	 */
	uint8_t map[MapWidth*MapHeight];
	///	Which level this is.
	/*!
		This is an index to the relevant file in the levels subdirectory.
	 */
	int levelIndex;

	///	The (moving) tiles in play.
	std::vector<ShooterTile *> tiles;
	///	Timer used to add new tiles.
	float tilesTimer;
	///	The speed at which new tiles are added.
	float tilesSpeed;

	///	Any explosions active on the level.
	std::vector<Explosion *> explosions;
	///	Any enemies on the level.
	std::vector<ShooterEnemy *> enemies;

	///	Used to determine whether the player matched the background level perfectly.
	int matchedTiles;
	///	Used to determine whether the player got the one-tile-only bonus.
	bool oneTileOnly;

	///	Used to display the level the player's supposed to create.
	int startTimer;
	///	Used to display the tileset's author.
	int authorTimer;

	///	Used to ensure TileSetFactory loads all the tiles.
	static bool loadTiles;
};

#endif
