//	TitleScreen.h - The title screen game state.
//  ----------------------------------------------------------------------------
//	This file is part of 'Tile Massacre Shmup', my entry to the TIGSource
//	Assemblee contest.
//	Copyright (C) 2009  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TITLESCREEN_H_
#define TITLESCREEN_H_

#include "GameState.h"
#include "TextScroller.h"

#include <stdint.h>

///	The title screen game state.
class TitleScreen : public GameState
{
  public:
	///	Constructor.
	TitleScreen(Application *app);
	///	Destructor.
	~TitleScreen();

	///	Draws the title screen.
	void draw(Drawer *d);

	///	Used to cycle through the button states.
	void keyDown(const SDL_keysym& keyPressed);

	///	Sets the high scores.
	void setHighScores(int *scores, std::string *names);

	///	Returns the name of this state.
	const std::string getName() const {return "TitleScreen";};
  private:
	///	The id of the background to draw.
	static uint32_t background;

	///	Displays the credits, amiga-style.
	TextScroller credits;

	///	The high scores.
	int *highScores;
	///	The high scores.
	std::string *highScoreNames;
};

#endif
